/*
 * Dash Media Player: External Interface Gateway 
 * Copyright (c) 2008 TMT Digital LLC.
 *
 * Author:  Travis Tidwell | http://www.travistidwell.com
 *
 * Dependencies:
 *    jQuery Library
 *
 * This script is used as a connection interface gateway to control the player from an external source.
 * It is also used as a means for communication between multiple instances of the Dash Media Player
 * on the page.  This allows you to separate the Playlist and the actual
 * player on the page, but yet have them behave as a single player.  For more information on how you can
 * integrate this great feature on your website, visit http://www.tmtdigital.com/remoteplaylist
 *
 * License: GPL
 */

var dashReady = false;
$(document).ready(dashInit);

//add jqwindow to href elements that have a class of .jqwindow
function dashInit() {
   dashReady = true;
}

function isDashReady() {
   return dashReady;
}

/** 
 * Loads a single node into the player.
 *
 * @param - The ID of the player you would like to send this request too.
 * @param - The node ID of the node you would like for this player to load.
 * @param - Boolean to indicate if you would like to increment the node counter on the load.
 */
function dashLoadNode( connectId, nodeId, incrementCounter ) {
   try {
      var dashObj = getDashObject( connectId );
      if( dashObj ) {    
          dashObj.loadNode( nodeId, incrementCounter );
      }
   }  
   catch(e) {
      alert( e );
   }
}

/** 
 * Sees if the player has already loaded a node.
 *
 * @param - The ID of the player you would like to send this request too.
 *
 * @return - Boolean (True if is has loaded content, False otherwise)
 */
function dashIsNodeLoaded( connectId ) {
   try {
      var dashObj = getDashObject( connectId );
      if( dashObj ) {
         return (dashObj.isNodeLoaded());
      }
   }  
   catch(e) {
      alert( e );
   }
}

/** 
 * Loads a playlist.
 *
 * @param - The ID of the player you would like to send this request too.
 * @param - The name of the playlist (view) you would like to load.
 */
function dashLoadPlaylist( connectId, playlist ) {
   try {
      var dashObj = getDashObject( connectId );
      if( dashObj ) {      
          dashObj.loadPlaylist( playlist );
      }
   }  
   catch(e) {
      alert( e );
   }
}

/** 
 * Loads the previous item in the playlist.
 *
 * @param - The ID of the player you would like to send this request too.
 * @param - Indicate if you would like for the player to loop to the end of the list if it is already
 *          on the first item.
 * @param - Indicate if you would like for the playlist to play the file after it loads it.
 */
function dashLoadPrev( connectId, loop, playAfter ) {
   try {
      var dashObj = getDashObject( connectId );
      if( dashObj ) {      
          dashObj.loadPrev( loop, playAfter );
      }
   }  
   catch(e) {
      alert( e );
   }
}

/** 
 * Loads the next item in the playlist.
 *
 * @param - The ID of the player you would like to send this request too.
 * @param - Indicate if you would like for the player to loop to the beginning of the list if it is already
 *          on the last item.
 * @param - Indicate if you would like for the playlist to play the file after it loads it.
 */
function dashLoadNext( connectId, loop, playAfter ) {
   try {
      var dashObj = getDashObject( connectId );
      if( dashObj ) {         
          dashObj.loadNext( loop, playAfter );
      }
   }  
   catch(e) {
      alert( e );
   }
}

/** 
 * Sets the filter argument for the playlist currently loaded.
 *
 * @param - The ID of the player you would like to send this request too.
 * @param - The argument that you would like to pass to your playlist to filter the content.
 * @param - The index of the argument.
 */
function dashSetFilter( connectId, argument, index ) {
   try {
      var dashObj = getDashObject( connectId );
      if( dashObj ) {         
          dashObj.setFilter( argument, index );
      }
   }  
   catch(e) {
      alert( e );
   }
}

/** 
 * Gets the Dash Player Object given an ID
 *
 * @param - The ID of the player you would like to send this request too.
 */
function getDashObject( connectId ){
   var dashObj = null;
	if (navigator.appName.indexOf( "Microsoft" ) != -1) {
      dashObj = window[connectId];
   }
	else {
      dashObj = window.document[connectId];
	}
	
	if( !dashObj ) {
	   alert( "Error: " + connectId + " not found!" );   
	}
	
	return dashObj;
}